.. EyeTrace documentation master file.

Welcome to EyeTrace's documentation!
=====================================

**EyeTrace** is an open-source toolkit for extracting ocular metrics and detecting fatigue from facial videos. It provides over 50 physiological and behavioral metrics, including pupil dynamics, eyelid movements, gaze patterns, head pose, and advanced signal analysis.

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
.. image:: https://img.shields.io/badge/python-3.8+-blue.svg
   :target: https://www.python.org/downloads/
.. image:: https://img.shields.io/github/actions/workflow/status/Xcept-Health/EyeTrace/ci.yml?branch=main
   :target: https://github.com/Xcept-Health/EyeTrace/actions
.. image:: https://readthedocs.org/projects/eyetrace/badge/?version=latest
   :target: https://eyetrace.readthedocs.io/

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   quickstart

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   modules

.. toctree::
   :maxdepth: 1
   :caption: Project Info

   contributing
   license
   citation

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`